@@ -16,6 +16,7 @@ import aws_cdk.aws_amplify._jsii
 import aws_cdk.aws_apigateway._jsii
 import aws_cdk.aws_apigatewayv2._jsii
 import aws_cdk.aws_appconfig._jsii
+import aws_cdk.aws_appflow._jsii
 import aws_cdk.aws_applicationautoscaling._jsii
 import aws_cdk.aws_applicationinsights._jsii
 import aws_cdk.aws_appmesh._jsii
@@ -35,6 +36,7 @@ import aws_cdk.aws_cloud9._jsii
 import aws_cdk.aws_cloudfront._jsii
 import aws_cdk.aws_cloudtrail._jsii
 import aws_cdk.aws_cloudwatch._jsii
+import aws_cdk.aws_codeartifact._jsii
 import aws_cdk.aws_codebuild._jsii
 import aws_cdk.aws_codecommit._jsii
 import aws_cdk.aws_codedeploy._jsii
@@ -125,6 +127,7 @@ import aws_cdk.aws_ssm._jsii
 import aws_cdk.aws_sso._jsii
 import aws_cdk.aws_stepfunctions._jsii
 import aws_cdk.aws_synthetics._jsii
+import aws_cdk.aws_timestream._jsii
 import aws_cdk.aws_transfer._jsii
 import aws_cdk.aws_waf._jsii
 import aws_cdk.aws_wafregional._jsii
@@ -136,9 +139,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/cloudformation-include",
-    "1.64.0",
+    "1.71.0",
     __name__[0:-6],
-    "cloudformation-include@1.64.0.jsii.tgz",
+    "cloudformation-include@1.71.0.jsii.tgz",
 )
 
 __all__ = [
